'use strict';

var _ = require('lodash');

exports.attributes = function (attr) {
    var template = {
        email: {
            type: 'email',
            unique: true
        },
        password: {
            type: 'STRING',
            minLength: 8
        },
        resetToken: {
            model: 'resetToken'
        }
    };

    if (attr.username) {
        delete(template.email);
    }

    _.merge(template, attr);
    _.merge(attr, template);
};

/**
 * used to hash the password
 * @param  {object}   values
 * @param  {Function} cb
 */
exports.beforeCreate = function (values) {
    if (!_.isUndefined(values.password)) {
        var header = values.password.substring(0,6) //check if the password is not already hashed
        if( header !== "{SSHA}" ){
            var ssha = require('ssha');
            var hash = ssha.create(values.password);
            values.password = hash;
        }
    }
};

/**
 * used to update the password hash if user is trying to update password
 * @param  {object}   values
 * @param  {Function} cb
 */
exports.beforeUpdate = function (values) {
    if (!_.isUndefined(values.password) && values.password !== null) {
        var header = values.password.substring(0,6) //check if the password is not already hashed
        if( header !== "{SSHA}" ) {
            var ssha = require('ssha');
            var hash = ssha.create(values.password);
            values.password = hash;
        }
    }
};
